% [sast,rast] = fnct_grph_sptr(stst,plgp,name,sbeg,sstp)
%
% single phophorylation trajectory
% calculates mean and standard deviation for RsbR and RsbS
% input:
%   stst: stressosome phosphorylations position and time separated (matrix)
%   plgp = 1: plots time trajectory (scalar)
%   name: name to save plot, if not to be save use '[]' (string)
%   sbeg: stress event begins (vector)
%   sstp: stress event stops (vector)
% 
% output:
%   sast: mean and s.d. for activation/phosphorylation over time for s
%   rast: mean and s.d. for activation/phosphorylation over time for r
%
% procedure:
%   Several statistics on stst-input.
%
% date: 11/05/10
% modification date: 11/05/10
%
% author: Ulf Liebal
% contact: ulfliebal@googlemail.com
% 
% please cite the original.


function [sast,rast] = fnct_grph_sptr(stst,plgp,name,sbeg,sstp)

sprs = [5,10,13,14,15,16,17,18,21,32]; % RsbS protein south
sprn = sort(61-sprs);
rsbs = [sprs,sprn];

rsbr = setdiff([1:60],rsbs);

    sact = sum(stst(rsbs,:))/length(rsbs);
    % fraction of activated/phosphorylated R proteins
    ract = sum(stst(rsbr,:))/length(rsbr);
    % mean and s.d. for activation/phosphorylation over time for S

    
tle2 = floor(size(stst,2)/2);
    
if ~exist('sbeg','var')
    sast(1) = mean(sact(:,tle2:end));
    sast(2) = std(sact(:,tle2:end));
    % mean and s.d. for activation/phosphorylation over time for S
    rast(1) = mean(ract(:,tle2:end));
    rast(2) = std(ract(:,tle2:end));
else
    sidx = [];
    for i1 = 1:length(sbeg)
        sidx = [sidx,[sbeg(i1):sstp(i1)]];
    end
    pidx = setdiff(1:size(stst,2),sidx);
    sacp = mean(stst(rsbs,pidx));
    % fraction of activated s peace time
    sacs = mean(stst(rsbs,sidx));
    % fraction of activated/phosphorylated R proteins
    racp = mean(stst(rsbr,pidx));
    % fraction of activated r peace time
    racs = mean(stst(rsbr,sidx));
    % mean and s.d. for activation/phosphorylation over time for s
    sast(1) = mean(sacp);
    sast(2) = std(sacp);
    sast(3) = mean(sacs);
    sast(4) = std(sacs);
    % mean and s.d. for activation/phosphorylation over time for r
    rast(1) = mean(racp);
    rast(2) = std(racp);
    rast(3) = mean(racs);
    rast(4) = std(racs);   
end

if exist('plgp','var') && plgp ==1
    set(0,'defaultaxesfontsize',18)
    set(0,'defaulttextfontsize',18)
    figure
    plot(sact,'xr')
    hold on
    plot(ract,'og')
    a=axis;
    a(4)=1;
    axis(a)
    xlabel('time')
    ylabel('phosphorylation level')
    legend('RsbS','RsbR')
    set(findobj(gcf,'Type','line'),'LineWidth',3);
    
    if ~exist('name','var')
        name = [];
    end
    if ~isempty(name)
        print('-dpng',name)
    end
end