% [xavg,yavg] = fnct_grph_tavrg(cstr,avrg,Rsb)
%
% calculate the average response (yavg) over several simulation steps (xavrg)
% The purpose of the function is primarily the smoothing of the results.
% input:
% cstr: step-wise specific phosphorylation of stressosome positions
% avrg: step-size over which the average is taken
% Rsb:  calculate average for either RsbS=1, or RsbR=2

function [xavg,yavg] = fnct_grph_tavrg(stst,avrg,Rsb)

sprs = [5,10,13,14,15,16,17,18,21,32]; % RsbS protein south
sprn = sort(61-sprs);
rsbs = [sprs,sprn];

rsbr = setdiff([1:60],rsbs);

sact = sum(stst(rsbs,:))/length(rsbs);
% fraction of activated/phosphorylated R proteins
ract = sum(stst(rsbr,:))/length(rsbr);
% mean and s.d. for activation/phosphorylation over time for S

stot = length(sact);
lnum = floor(stot/avrg); % number of loops to determine new average. equals the new number of simulation steps.

lpos = 1;

if Rsb==2
    for i0 = 1:lnum
        xavg(i0) = mean(lpos:lpos+(avrg-1));
        yavg(i0) = mean(ract(lpos:lpos+(avrg-1)));
        lpos=lpos+avrg;
    end
else
    for i0 = 1:lnum
    xavg(i0) = mean(lpos:lpos+(avrg-1));
    yavg(i0) = mean(sact(lpos:lpos+(avrg-1)));
    lpos=lpos+avrg;
    end
end