%% graphical representation of the stressosome icosaheder. 
% each protein position is codified with surface coordinates. 

function liebal_2DSurfStress
%% longitudes polar and arctic for southern hemisphere
lpas = [7;9;19;21;27;5;11;17;23;29];
lpan = [2;8;14;20;26;4;10;12;22;24];
apas = [0.5;1;1;1;0.5;2;2;2;2;2];
% longitudes tropic for southern hemisphere
lt_s = [1;3;7;9;13;15;19;21;25;27];
at_s = ones(10,1)*3;
% longitudes equatorial for southern hemisphere
le_s = [4;6;10;12;16;18;22;24;28;30];
ae_s = ones(10,1)*4;

% protein coordinates south
pcos = [lpas,apas;lt_s,at_s;le_s,ae_s];
pcon = [lt_s,ones(10,1)*5;le_s,ones(10,1)*6;lpan,[7;7;7;7;7;8.5;8;8;8;8.5]];

pcoa = [pcos;pcon];
% % connectivity table
% ctab = [2,5,6;1,3,7;2,4,8;3,5,9;4,1,10;... % polar south 5 rows
% 	    1,12,13;2,14,15;3,16,17;4,18,19;5,20,11;... % arctic south 5 rows
% 	    12,10,30;11,6,21;14,6,22;13,7,23;16,7,24;15,8,25;18,8,26;17,9,27;20,9,28;19,10,29;... % tropic south 10 rows
% 		12,22,32;13,21,33;14,24,34;15,23,35;16,26,36;17,25,37;18,28,38;19,27,39;20,30,40;11,29,31 ...% equator south 10 rows
%         ]; 
% 	
% ctab = [ctab;(60-ctab(61-[31:60],:))+1]; % northern protein hemisphere


% coordinates of t neighbourhoods
ct1a = [5,10,13,14,15,16,17,18,21,32,29,40,43,44,45,46,47,48,51,56];

ct2a1 = [1,4,6,9,11,12,23,24,25,26,27,30];
ct2a2 = sort(61-ct2a1);
ct2a = [ct2a1,ct2a2];

ct3a = [7,8,20,22,39,41,53,54];

ct4a = [2,3,19,28,33,42,58,59];

% connectivity table, first entry shows unique neighbour, i.e. either R in
% RSS or S in SRR
cts1 = [10,4,1;5,11,20;14,6,22;13,7,23;16,7,24;15,8,25;18,8,26;17,9,27;32,12,22;21,31,41]; 
ctn1 = 61-cts1;
cta1 = [cts1;[ctn1([11-(1:10)],:)]]; % t1a connections, dimer partners are first entry

cts2 = [5,2,6;5,3,9;13,12,1;18,19,4;10,30,12;21,6,11;14,24,34;15,23,35;16,26,36;17,25,37;18,28,38;29,11,31];
ctn2 = 61-cts2;
cta2 = [cts2;[ctn2([13-(1:12)],:)]]; % t2a connections, dimer partners are last entry

cts3 = [2,14,15;3,16,17;19,10,29;33,13,21];
ctn3 = 61-cts3;
cta3 = [cts3;[ctn3([5-(1:4)],:)]]; % t3a connections, dimer partners are first entry

cts4 = [7,1,3;8,2,4;20,9,28;39,27,19];
ctn4 = 61-cts4;
cta4 = [cts4;[ctn4([5-(1:4)],:)]]; % t4a connections, dimer partners are first entry

ctab(ct1a,:) = cta1;
ctab(ct2a,:) = cta2;
ctab(ct3a,:) = cta3;
ctab(ct4a,:) = cta4;

% dimer table, here all true dimers are listed
dits = [1,6;2,7;3,8;4,9;5,10;11,12;13,14;15,16;17,18;19,20];
dite = [[21:30]',[32:40,31]'];
ditn = sort(61-dits);
dita = [dits;dite;ditn];

% defining RsbS dimers
sdid = [5,7,8,9,11,19,22,23,24,26]; % index positions in dita for RsbS dimers
sdim = dita(sdid,:);
% defining RsbR dimers
rdid = setdiff([1:30],sdid);
rdim = dita(rdid,:);

% defining positions of RsbS
sprs = [5,10,13,14,15,16,17,18,21,32]; % RsbS protein south
sprn = sort(61-sprs);
rsbs = [sprs,sprn];

rsbr = setdiff([1:60],rsbs);

figure;hold on;
for i1 = 1:size(ctab,1)
%    text(pcoa(i1,1),pcoa(i1,2),num2str(i1),'HorizontalAlignment','center','VerticalAlignment','middle','fontweight','bold','fontsize',12)
 	line([pcoa(i1,1),pcoa(ctab(i1,1),1)],[pcoa(i1,2),pcoa(ctab(i1,1),2)],'color','k','linestyle',':')
 	line([pcoa(i1,1),pcoa(ctab(i1,2),1)],[pcoa(i1,2),pcoa(ctab(i1,2),2)],'color','k','linestyle',':')
 	line([pcoa(i1,1),pcoa(ctab(i1,3),1)],[pcoa(i1,2),pcoa(ctab(i1,3),2)],'color','k','linestyle',':')
end
for i1 = 1:size(sdim)
    line([pcoa(sdim(i1,1),1),pcoa(sdim(i1,2),1)],[pcoa(sdim(i1,1),2),pcoa(sdim(i1,2),2)],'color','r','linewidth',3) 
end
for i1 = 1:size(rdim)
    line([pcoa(rdim(i1,1),1),pcoa(rdim(i1,2),1)],[pcoa(rdim(i1,1),2),pcoa(rdim(i1,2),2)],'color','b','linewidth',3) 
end
scatter(pcoa(rsbr,1),pcoa(rsbr,2),150,'o','filled')
scatter(pcoa(rsbs,1),pcoa(rsbs,2),200,'r','p','filled')
 
 axis off