%% workflow for generating stressosome dynamics.
% generated by: Ulf Liebal
% contact: ulfliebal@googlemail.com
% please cite the original

set(0,'defaultaxesfontsize',30)
set(0,'defaulttextfontsize',30)

%% Reproduction of two-dimensional stressosome network
liebal_2DSurfStress


%% multiple simulations of stressosome
% The cell simulates an ensemble of stressosomes and determines the average
% phosphorylation level of RsbR and RsbS over the simulation steps (time). 
% The user can set a stress stimulus (sbeg until sstp).
nstr = 30; % number of simulated stressosomes used for statistics

step = 50; % update steps for dynamics, equivalent to time

% for details to the parameter values have a look to the
% protein-cooperation tables
kphr = .1; % phosphorylation propensity for R
kdpr = .06; % dephosphorylation propensity for R
kphs = .6; % phosphorylation propensity for S
kdps = 1;  % dephosphorylation propensity for S
ppar = [kphr;kdpr;kphs;kdps];
spar = 1; % stress parameter new value
ttab = @liebal_stressosome11_Protcoop_proact; % file that determines protein cooperative details
% other protein cooperation table are:
% @liebal_stressosome11_Protcoop_nocoop
% @liebal_stressosome11_Protcoop_proact
% @liebal_stressosome11_Protcoop_subact

sbeg = [30]; % stress event begins
sstp = [49]; % stress event stops

cstr = zeros(60,step+1);
for i1 = 1:nstr
    stst = fctn_bool_single(ppar,step,ttab,sbeg,sstp,spar); % stressosome dynamics simulated here
    cstr = cstr+stst; % collected stressosome phosphorylations position and time separated
end
cstr = cstr./nstr; % collected phosphorylation average per stressosome

[a,b]=fnct_grph_sptr(cstr,1,[],sbeg,sstp) % graphical representation, single phophorylation trajectory
% save filename cstr stst kphr kdpr kphs kdps spar ttab sbeg sstp step nstr

%% plotting simulation and kim data
clear all

sprs = [5,10,13,14,15,16,17,18,21,32]; % RsbS protein south
sprn = sort(61-sprs);
rsbs = [sprs,sprn];
rsbr = setdiff([1:60],rsbs);

figure; box; hold on
plot(16,.4,'k^','markerfacecolor','k')
plot(16,.4,'s','color',[.5,.5,.5],'markerfacecolor',[.5,.5,.5])
plot(16,.4,'r-')
plot(16,.4,'g-')
plot(16,.4,'b-')

load 1112_data_strsme-phos_subact
sact = sum(cstr(rsbs,:))/length(rsbs);
% fraction of activated/phosphorylated R proteins
ract = sum(cstr(rsbr,:))/length(rsbr);
% mean and s.d. for activation/phosphorylation over time for S
plot(0:20,ract(50:70),'-','color',[0,1,0])
plot(0:20,sact(50:70),'-','color',[0,.5,0])
load 1112_data_strsme-phos_nocoop
sact = sum(cstr(rsbs,:))/length(rsbs);
% fraction of activated/phosphorylated R proteins
ract = sum(cstr(rsbr,:))/length(rsbr);
% mean and s.d. for activation/phosphorylation over time for S
plot(0:20,ract(50:70),'-','color',[0,0,1])
plot(0:20,sact(50:70),'-','color',[0,0,.5])
load 1112_data_strsme-phos_proact
sact = sum(cstr(rsbs,:))/length(rsbs);
% fraction of activated/phosphorylated R proteins
ract = sum(cstr(rsbr,:))/length(rsbr);
% mean and s.d. for activation/phosphorylation over time for S
plot(0:20,ract(50:70),'color',[1,0,0])
plot(0:20,sact(50:70),'color',[.5,0,0])

kimdat = csvread('kim_in-vivo-stressosome-phosph_04_data-fig3.csv',1,0)
rstt(:,1) = mean(kimdat(:,[2,4]),2);
rstt(:,2) = std(kimdat(:,[2,4]),0,2);
sstt(:,1) = mean(kimdat(:,[3,5]),2);
sstt(:,2) = std(kimdat(:,[3,5]),0,2);
errorbar(kimdat(:,1),rstt(:,1),rstt(:,2),'k^')
errorbar(kimdat(:,1),sstt(:,1),sstt(:,2),'s','color',[.5,.5,.5],'markerfacecolor',[.5,.5,.5])
%plot(kimdat(:,1),kimdat(:,[2,4]),'k^','markerfacecolor','b')
%plot(kimdat(:,1),kimdat(:,[3,5]),'s','color',[.5,.5,.5],'markerfacecolor',[.5,.5,.5])

a=axis;
a=[-.5,21,0,1];
axis(a)

xlabel('time in min')
ylabel('phosphorylation level')
legend('RsbR','RsbS','pro-act','sub-act','no-coop')
set(findobj(gcf,'Type','line'),'LineWidth',3);

% print('-dpng',['/users/sbi00/uliebal/Documents/yang/rostock/sysmo1_bacell/models/struct_stress/p1012/data/Str-mono_fract-phos.png'])
%% analysis of jons stimulus response data
% sigmoidal shape captured by hyperbolic tangens:
%  f(x) = a/2(tanh(b(x-c))+1)+d)
%  a: width from lowest to highest f(x)
%  b: steepness of the transition
%  c: position of the inflection
%  d: distance from 0 for lowest f(x)

jonetoh = csvread('marles-wright_struct-stressosome_08_EtOH-data-fig4.csv',1,0)
jonnacl = csvread('marles-wright_struct-stressosome_08_NaCl-data-fig4.csv',1,0)

f = @(p,x) p(1)./2.*(tanh(p(2).*(x-p(3)))+1)+0;
%cmap = colormap(jet(size(dsrc,1)));
%mmap = ['x','n','n','n','o'];
%lmap = ['-','--','-.',':','-'];
set(0,'defaultaxesfontsize',18)
set(0,'defaulttextfontsize',18)
figure; hold on; box

% estimating simgoidal properties of jons etoh experiment
tetf = nlinfit(jonetoh(:,1),jonetoh(:,2),f,[100,.7,2.5]); % tangens etoh fit
% plot(jonetoh(:,1),jonetoh(:,2),'o')
% plot(jonetoh(:,1),f(tetf,jonetoh(:,1)))
% normalising the data
njet(:,1) = jonetoh(:,1)./tetf(3);
njet(:,2) = jonetoh(:,2)./tetf(1);

% estimating simgoidal properties of jons etoh experiment
tnaf = nlinfit(jonnacl(:,1),jonnacl(:,2),f,[60,.1,487]); % tangens nacl fit
njna(:,1) = jonnacl(:,1)./tnaf(3);
njna(:,2) = jonnacl(:,2)./tnaf(1);

plot(njet(:,1),njet(:,2),'bo')
plot(njna(:,1),njna(:,2),'rd')

xlabel('Stimulus')
ylabel('Response')
legend('EtOH','NaCl','location','NW')
% 
set(findobj(gcf,'Type','line'),'LineWidth',3);
% print('-dpng',['/users/sbi00/uliebal/Documents/yang/rostock/sysmo1_bacell/models/struct_stress/p1012/data/1111_stimulus-VS-response_jon-data'])
%% computing & plot of kphr variance
f = @(p,x) p(1)./2.*(tanh(p(2).*(x-p(3)))+1)+0;

load 1112_data_strsme-phos-kdpr06r3-1-nocoop
ncof = nlinfit(kphr',sast(:,1),f,[.8,9,.07]); % tangens fit
[a,b]=sort(kphr);
nxdn = kphr(b)'./ncof(3);
nydn = sast(b,1)./ncof(1);
figure; hold on
% plot(kphr,sast(:,1),'x')
% plot(sort(kphr),f(ncof,sort(kphr)),'-b')
plot(nxdn,nydn,'^b')

load 1112_data_strsme-phos-kdpr06r3-1-subact
scof = nlinfit(kphr',sast(:,1),f,[.8,9,.07]);
[a,b]=sort(kphr);
sxdn = kphr(b)'./scof(3);
sydn = sast(b,1)./scof(1);
plot(sxdn,sydn,'^g')
% plot(kphr,sast(:,1),'xg')
% plot(sort(kphr),f(scof,sort(kphr)),'-g')

load 1112_data_strsme-phos-kdpr06r3-1-proact
pcof = nlinfit(kphr',sast(:,1),f,[.8,9,.07]);
[a,b]=sort(kphr);
pxdn = kphr(b)'./pcof(3);
pydn = sast(b,1)./pcof(1);
plot(pxdn,pydn,'^r')
% plot(kphr,sast(:,1),'xr')
% plot(sort(kphr),f(pcof,sort(kphr)),'-r')

a=axis;
a(2)=2.5;
axis(a)
%% plot of jons experiments and my simulations, evaluate the previous two cells
figure; hold on
% jons data
plot(njet(:,1),njet(:,2),'ko','markerfacecolor','k')
plot(njna(:,1),njna(:,2),'k^','markerfacecolor','k')

plot(nxdn,nydn,'b') % no cooperativity
plot(sxdn,sydn,'g') % substrate cooperativity
plot(pxdn,pydn,'r') % product cooperativity
a=axis;
a([2,4])=[1.9,1.05];
axis(a)
box
xlabel('Stimulus')
ylabel('Response')
set(findobj(gcf,'Type','line'),'LineWidth',3)
legend('EtOH','NaCl','no-coop','sub-act','pro-act')
% print('-dpng',['/users/sbi00/uliebal/Documents/yang/rostock/sysmo1_bacell/models/struct_stress/p1012/data/Str-mono_sign-resp.png'])
%% reproduction of RsbX experiments by Voelker
figure; hold on; box
% loading experimental data
% we normalise the response using the assumption that the wild type
% displayed maximum activity at time 45 which is 49, and this equals the
% wild type normal response. All values divided by 49.
vdat = csvread('voelker_rsbx-experiment_97_data-fig1.csv',1,0)
vdnorm = max(vdat(:,2));
vdat(:,[2,3,4])=vdat(:,[2,3,4])/vdnorm;
plot(vdat(:,1),vdat(:,2),'rs','markersize',8,'markerfacecolor','r')
plot(vdat(:,1),vdat(:,3),'gd','markersize',8,'markerfacecolor','g')
plot(vdat(:,1),vdat(:,4),'b^','markersize',8,'markerfacecolor','b')

% We need to find the positions of RsbR and RsbS in the solution vector.
% These indices are determined in the following
sprs = [5,10,13,14,15,16,17,18,21,32]; % RsbS protein south
sprn = sort(61-sprs); % those in the north stressosome hemisphere
rsbs = [sprs,sprn];
rsbr = setdiff([1:60],rsbs);

% reference experiment
load 1112_data_strsme-phos_voelker-wt
sact = sum(cstr(rsbs,:))/length(rsbs);
% fraction of activated/phosphorylated S proteins
% now also normalisation of all simulated data with the maximum S
% phosphorylation of the wt. the first entry is too high because it is
% generated by random initialisation, thus we omit the first entry.
snorm = max(sact(10:end));
sact=sact/snorm;
plot(0:5:100,sact(50:5:150),'r')
% explaining experiment with decrease of RsbX dependent RsbS
% dephosphorylation
load 1112_data_strsme-phos_voelker-kdps06
sact = sum(cstr(rsbs,:))/length(rsbs);
% fraction of activated/phosphorylated S proteins
% now also normalisation of all simulated data with the maximum S
% phosphorylation of the wt. the first entry is too high because it is
% generated by random initialisation, thus we omit the first entry.
sact=sact/snorm;
plot(0:5:100,sact(50:5:150),'g')
load 1112_data_strsme-phos_voelker-kdps03
sact = sum(cstr(rsbs,:))/length(rsbs);
% fraction of activated/phosphorylated S proteins
% now also normalisation of all simulated data with the maximum S
% phosphorylation of the wt. the first entry is too high because it is
% generated by random initialisation, thus we omit the first entry.
sact=sact/snorm;
plot(0:5:100,sact(50:5:150),'b')

set(findobj(gcf,'Type','line'),'LineWidth',3);

xlabel('time in min')
ylabel('response relative to max wt')
legend('wt','RsbX reduced','RsbX low','location','best')
% 
% print('-dpng',['/users/sbi00/uliebal/Documents/yang/rostock/sysmo1_bacell/models/struct_stress/p1012/data/Str-mono_voelker.png'])

%% reproduction of the results by akbar et al., 2001
% the authors make experiments with various RsbR deletion mutants

% first: wildtype simulations
nstr = 30; % number of simulated stressosomes used for statistics
step = 50; % update steps for dynamics, equivalent to time

% for details to the parameter values have a look to the
% protein-cooperation tables
% reproducing three experiments by Akbar:
sval = [0.6;0.75;0.9]; %, optimal values for reproduction of Akbar are 0.6 (wt), 0.7 (RsbD), 0.9 (RsbC)
cstr = zeros(60,step+1,length(sval));

for i0 = 1:length(sval)
kphr = .1; % phosphorylation propensity for R
kdpr = .06; % dephosphorylation propensity for R
kphs = sval(i0); % phosphorylation propensity for S
kdps = 1;  % dephosphorylation propensity for S
ppar = [kphr;kdpr;kphs;kdps];
spar = 1; % stress parameter new value
ttab = @liebal_stressosome11_Protcoop_proact; % file that determines protein cooperative details

sbeg = [30]; % stress event begins
sstp = [49]; % stress event stops

for i1 = 1:nstr
    stst = fctn_bool_single(ppar,step,ttab,sbeg,sstp,spar); % stressosome dynamics simulated here
    cstr(:,:,i0) = cstr(:,:,i0)+stst; % collected stressosome phosphorylations position and time separated
end
cstr(:,:,i0) = cstr(:,:,i0)./nstr; % collected phosphorylation average per stressosome
end
% plotting of average stressosome activation over x-timesteps
avrg = 3; % determines the averaged step-size (smoothing)
[xav1,yav1] = fnct_grph_tavrg(cstr(:,:,1),avrg,1);
[xav2,yav2] = fnct_grph_tavrg(cstr(:,:,2),avrg,1);
[xav3,yav3] = fnct_grph_tavrg(cstr(:,:,3),avrg,1);
figure; hold on; box
plot(xav1,yav1,'-ok','MarkerFaceColor','w','MarkerSize',15)
plot(xav2,yav2,'-ok','MarkerFaceColor','k','MarkerSize',15)
plot(xav3,yav3,'-sk','MarkerFaceColor','k','MarkerSize',15)
legend('0.6','0.75','0.9','Location','best')
xlabel('time in min')
ylabel('phosphorylation level')
set(findobj(gcf,'Type','line'),'LineWidth',3);
% print('-dpng',['1205_time-VS-RsbS-phosphorylation_akbar-reproduction'])

%%
