% [t1a,t2a,t3a,t4a] = liebal_stressosome11_Protcoop_nocoop
% 
% function that determines the values of protein cooperativity. Used as
% input for fctn_bool_single.m
%
% for optimal stressosome simulation use the following parameter values
% kphr = (0.1/1) unstressed/stressed (0.3/0.7)
% kdpr = 0.04
% kphs = 0.3  
% kdps = 1
%
% date: 2011/05/09
% modification date: 2011/11/18
%
% author: Ulf Liebal
% contact: ulfliebal@googlemail.com
% 
% please cite the original.

function [t1a,t2a,t3a,t4a] = liebal_stressosome11_Protcoop_nocoop
% truth tables
% t1 is for S neighbourhood S-R-R, the first number in the tuple gives the
% amount of phosphorylations of S the second of R, the third 
% the future state of the center
t1a = [0,0,0;...
	   0,1,0;...
	   0,2,1;...
	   1,0,0;...
	   1,1,0;...
	   1,2,0];
% t2 is for R neighbourhood S-R-R, the first number in the tuple gives the
% amount of phosphorylations of S the second of R, the third 
% the future state of the center
t2a = [0,0,1;...
	   0,1,1;...
	   0,2,1;...
	   1,0,1;...
	   1,1,1;...
	   1,2,1];
% t3 is for R neighbourhood R-S-S, the first number in the tuple gives the
% amount of phosphorylations of R the second of S, the third 
% the future state of the center
t3a = [0,0,1;...
	   0,1,1;...
	   0,2,1;...
	   1,0,1;...
	   1,1,1;...
	   1,2,1];
% t4 is for R neighbourhood R-R-R, the first number in the tuple gives the
% amount of phosphorylations, the second the future state of the center
t4a = [0,1;...
	   1,1;...
	   2,1;...
	   3,1];
