function outp = lathypsam(rnge,cntr,csmp,dstr,grph)

% latin hypercube sampling
%
% The function determines random numbers in small user defined intervals 
% and distributions. Within the container a random number is selected with
% a uniform probability in the container range. The produced number of
% random samples will be one less than the input parameter nsmp.
%
% input:
%    rnge: range, 2x2 vector, contains lower and upper boundaries for 
%          sampling for each of two dimensions. First row first dimension,
%          second row second dimension, first column lower boundary, second
%          column high boundary
%    cntr: number of container to sample in, scalar or vector, if a scalar
%          then the number of container is equal for both dimensions, the
%          sampling is true cubic
%    csmp: container samples, scalar, number of samples for each container
%    dstr: distribution, vector, choose between uniform (1) or logarithmic
%          distribution of containers for each dimension.
%    grph: graphics, scalar, no input: no graphic output, input: graphic
%          output of the distribution
%
% output:
%    outp: nsmpx1 vector, with random distribution

% generating the container
if length(cntr) == 1
    cntr=[cntr,cntr];
end
if size(rnge,1)==1
    rnge=[rnge;rnge];
end
if dstr == 1
    cnta = linspace(rnge(1,1),rnge(1,2),cntr(1)+1);
    cntb = linspace(rnge(2,1),rnge(2,2),cntr(2)+1);
elseif dstr == 2
    cnta = logspace(log10(rnge(1,1)),log10(rnge(1,2)),cntr(1)+1);
    cntb = logspace(log10(rnge(2,1)),log10(rnge(2,2)),cntr(2)+1);
else
    error('enter valid distribution classifier -dstr-')
end
[fcna,fcnb] = meshgrid(cnta(1:end-1),cntb(1:end-1)); % generating lower container boundary
[hcna,hcnb] = meshgrid(cnta(2:end),cntb(2:end)); % generating high container boundary
nfcna = reshape(fcna,[size(fcna,1)*size(fcna,2),1]);
nfcnb = reshape(fcnb,[size(fcna,1)*size(fcna,2),1]);
nhcna = reshape(hcna,[size(hcna,1)*size(hcna,2),1]);
nhcnb = reshape(hcnb,[size(hcna,1)*size(hcna,2),1]);
lntv = [nfcna,nfcnb]; % container low boundary
hntv = [nhcna,nhcnb]; % container high boundary

% determining random numbers in the container
outp = zeros(size(lntv,1)*csmp,2);
for i0 = 1:size(lntv,1)
    outp((i0-1)*csmp+1:i0*csmp,1) = rand(csmp,1)*(hntv(i0,1)-lntv(i0,1))+lntv(i0,1);
    outp((i0-1)*csmp+1:i0*csmp,2) = rand(csmp,1)*(hntv(i0,2)-lntv(i0,2))+lntv(i0,2);
end

if exist('grph','var')
    figure
    plot(outp(:,1),outp(:,2),'*')
    for i0 = 1:length(cnta)
        line([cnta(i0),cnta(i0)],[cntb(1),cntb(end)])
    end
    for i0 = 1:length(cntb)
        line([cnta(1),cnta(end)],[cntb(i0),cntb(i0)])
    end
end