function outp = lathypsam(rnge,nsmp,dist)

% latin hypercube sampling
%
% The function determines random numbers in small user defined intervals 
% and distributions. Within the container a random number is selected with
% a uniform probability in the container range. The produced number of
% random samples will be one less than the input parameter nsmp.
%
% input:
%    rnge: range, 2x1 vector, contains lower and upper boundaries for sampling
%    nsmp: number of samples, scalar, contains the number of total samples,
%          and corresponds of the number of container within the boundary
%    dist: distribution, scalar, choose between uniform (1) or logarithmic
%          distribution of containers.
%
% output:
%    outp: nsmpx1 vector, with random distribution

% generating the container
if dist == 1
    cont = linspace(rnge(1),rnge(2),nsmp);
elseif dist == 2
    cont = logspace(log10(rnge(1)),log10(rnge(2)),nsmp);
else
    error('enter valid distribution classifier -dist-')
end

% finding random number in the container
for i0 = 1:nsmp-1
    outp(i0) = rand*(cont(i0+1)-cont(i0))+cont(i0);
end

% permutating the result that everything looks random
shff = randperm(nsmp-1);
outp = outp(shff);