% simulation and graphical presentation of a model for the Study:
% 'Controlled sigmaB induction in shake flask' with Assay: 'IPTG induction
% of sigmaB in BSA115'.
%  
% Author: Ulf Liebal
% for questions and comments please give me notice at:
%         ulf.liebal@uni-rostock.de
%
% necessary files:
%   ODE-models:
%       bacell_0910_liebal_BSA115_3IPTG_ptscr.m
%       bacell_0910_liebal_BSA115_3IPTG_sbdeg.m
%       bacell_0910_liebal_BSA115_3IPTG_tscrinh.m
%
%   experiment file:
%       090915_BSA115BSA46_IPTGassay.csv
%
% Make sure these files are in the current folder of matlab.
%% loading experimental data
dats = csvread('090915_BSA115BSA46_IPTGassay.csv',1,0);
% the first row represents the time in minutes
% second row: BSA115 negative control with no added IPTG
% third row:  BSA115 + 0.1 mM IPTG at 95 min
% fourth row: BSA115 + 0.2 mM IPTG at 95 min
% fith row:   BSA115 + 1 mM IPTG at 95 min

%% Plotting the models on the experimental data
% first plotting the experimental data
figure
plot(dats(:,1)-95,dats(:,[2:5]),'o')

simulate_model = @bacell_0910_liebal_BSA115_3IPTG_ptscr;
% choose here the model to be simulated:
%     @bacell_0910_liebal_BSA115_3IPTG_ptscr
%     @bacell_0910_liebal_BSA115_3IPTG_sbdeg
%     @bacell_0910_liebal_BSA115_3IPTG_tscrinh

inic = simulate_model();
% Initial conditions [sigB,regB,lacZ]=[0,0,0]
parv = simulate_model('parametervalues');
% Parameter values:
% 1.IPTG (concentration), 2.kbs (sigB expression),
% 3. kbd (sigB dilution/degradation), 4. kzs (lacZ expression), 
% 5. kzd (LacZ degradation.dilution), 6. kzr (degradation due to RegB), 
% 7. krs (regB expression) and 8. krd (RegB degradation/dilution)
% The IPTG concentration is by default at 0.1 mM.

% simulation of LacZ activity in Miller Units for 0.1 mM IPTG
[t,y] = ode15s(simulate_model,[0 400],inic);
hold on
plot(t,y(:,2),'g')

% simulation of LacZ activity in Miller Units for 0.1 mM IPTG
parv(1) = 200; % setting IPTG parameter to 0.2 mM
[t,y] = ode15s(simulate_model,[0 400],inic,[],parv);
plot(t,y(:,2),'r')

% simulation of LacZ activity in Miller Units for 0.1 mM IPTG
parv(1) = 1000; % setting IPTG parameter to 1 mM
[t,y] = ode15s(simulate_model,[0 400],inic,[],parv);
plot(t,y(:,2),'c')

xlabel('time in minutes')
ylabel('Miller Units')
legend('0 IPTG','100 umol','200 umol','1 mmol','location','ne')
set(findobj(gcf,'Type','line'),'LineWidth',3);
%% Plotting post-transcriptional instability model on experimental results
%  of BSG56 with regular activation of sigmaB by starvation and functional
%  upstream regulation by anti sigma factors

figure; hold on; box

simulate_model = @bacell_0910_liebal_BSA115_3IPTG_ptscr;
inic = simulate_model();
% Initial conditions [sigB,regB,lacZ]=[0,0,0]
parv = simulate_model('parametervalues');
parv(1) = 28.9;
parv(4) = 8.2e-6;
[t,y] = ode15s(simulate_model,[0 500],inic,[],parv);
plot((t+300)/60,y(:,2),'r')

simulate_model = @igoshin_sigbmdl;
inic = simulate_model();
[t,y] = ode15s(simulate_model,[0 800],inic);
plot(t/60,y(:,10),'--b');

% loading experimental data
dats = csvread('meas_od-gal_x2_t780.csv',1,0);
% the first row represents the time in minutes
% second row: BS56 beta-Gal activity in Miller Units
plot(dats(:,1)/60,dats(:,2),'kx')

xlabel('time in hours')
ylabel('Miller Units')
legend('prot Model','sigB fbck. Model','Exp. Data','location','best')
set(findobj(gcf,'Type','line'),'LineWidth',3);